# 🐍 TamilPP (Tamil Python Compiler)

TamilPP is a powerful, fully-featured programming language compiler that allows you to write Python logic using native Tamil words or Tanglish. 

## Installation
```bash
pip install tamilpp